package com.jeethink.system.service;

import java.util.List;
import com.jeethink.system.domain.CeshiInfo;
import org.springframework.transaction.annotation.Transactional;

/**
 * 测试Service接口
 * 
 * @author sh
 * @date 2022-03-01
 */
public interface ICeshiInfoService 
{
    /**
     * 查询测试
     * 
     * @param ceshiId 测试ID
     * @return 测试
     */
    public CeshiInfo selectCeshiInfoById(String sql);

    /**
     * 查询测试列表
     * 
     * @param ceshiInfo 测试
     * @return 测试集合
     */
    public List<CeshiInfo> selectCeshiInfoList(CeshiInfo ceshiInfo);

    /**
     * 新增测试
     * 
     * @param ceshiInfo 测试
     * @return 结果
     */

    public int insertCeshiInfo(CeshiInfo ceshiInfo);

    /**
     * 修改测试
     * 
     * @param ceshiInfo 测试
     * @return 结果
     */
    public int updateCeshiInfo(CeshiInfo ceshiInfo);

    /**
     * 批量删除测试
     * 
     * @param ceshiIds 需要删除的测试ID
     * @return 结果
     */
    public int deleteCeshiInfoByIds(String[] ceshiIds);

    /**
     * 删除测试信息
     * 
     * @param ceshiId 测试ID
     * @return 结果
     */
    public int deleteCeshiInfoById(String ceshiId);
}
